@@ -1,13 +1,11 @@
 import pydantic
 
-from typing import Any
+from .plugin import Plugin
+from typing import List
 
 
 class CollectorConfig(pydantic.BaseSettings):
     default_pulling_interval: int
     token: str
-    plugins: Any
+    plugins: List[Plugin]
     platform_host_url: str
-
-    class Config:
-        smart_union = True
